function [f,t]=DFT(v,x)
%DFT - compute the Discrete Fourier Transform using trig basis fns
%
% Syntax: f=DFT(v,x)
%
% Input: 
%	v = vector of sampled data, or a matrix of column vectors 
% 	x = optional vector of sample times/locations (equally spaced)
%		default = equally spaced points over interval [0, 2pi]
%
% Output:
%	f = col vector of Fourier coefficients.  Order is a0/sqrt(2), a1, b1, 
%		a2, b2, ... aD, bD, where D = number of data points in vector v.
%	t = vector of sample angles returned by MakeTrig
%
% LNT 20-Feb-03 for V791 class

[r,c] = size(v);		% check if v is a row or col vector
if r==1
	v=v';				% force data to be a column vector
end
[D,c] = size(v);		% get input dimensions

if nargin < 2 || isempty(x)
	x = D;				% dimensionality = # of rows in data vector
end
[M,t]=MakeTrig(x);		% build the transformational matrix
f = sqrt(2/D) * M*v;	% compute Fourier coefficients for all columns in matrix v

% M*M'					% test for ortho-normality
% data = sqrt(D/2) * M'*f	% check: re-compute data from Fourier coefficients 

% end of function DFT.m
