function [v,x]=IDFT(f,t)
%IDFT - compute the Inverse Discrete Fourier Transform using trig basis fns
%
% Syntax: [v,x]=IDFT(f,t)
%
% Input: 
%	f = vector of Fourier coefficients or a matrix of col vectors.  
%       Order is a0/sqrt(2), a1, b1, a2, b2, ... aD, bD,
%		 where D = number of data points, 
% 	t = optional vector of sample times (interval [0 L] or angles (interval [0 2pi])
%		default = equally spaced points over interval [0, 2pi]
%
% Output:
%	v = vector of sampled data points, or a matrix of column vectors
% 	x = vector of sample angles used for reconstructing the signal
%
% LNT 20-Feb-03 for V791 class

[r,c] = size(f);		% check if f is a row or col vector
if r==1
	f=f';				% force data to be a column vector
end
[D,c] = size(f);		% get input dimensions

if nargin < 2
	t = D;				% dimensionality = # of rows in Fourier vector
end

[M,x]=MakeTrig(t);		% build the transformational matrix

v = sqrt(D/2) * M'*f;	% reconstruct data from Fourier coefficients 

% end of function IDFT.m

