function [f,t]=cDFT(v,x)
%DFT - compute the Discrete Fourier Transform using complex exponential basis fns
%
% Use: [f,t]=cDFT(v,x)
%
% Input: 
%	v = vector of sampled data, or a matrix of column vectors 
% 	x = vector of sample times/locations (equally spaced)
%		default = equally spaced points over interval [0, 2pi]
%
% Output:
%	f = vector of Fourier coefficients.  Order is c(k=-D/2), ..., c(-1), c(0), c(1),...,c(k=D/2)
%		where k = harmonic #, D = # data points 
%	t = vector of sample angles returned by BuildCExp.m
%
% LNT 20-Feb-03

[r,c] = size(v);		% check if v is a row or col vector
if r==1
	v=v';				% force data to be a column vector
end
[D,c] = size(v);		% get input dimensions

if nargin < 2
	x = D;				% dimensionality = # of rows in data vector
end
x
[M,t]=BuildCExp(x);		% build the transformational matrix
f = sqrt(1/D) * M*v;	% compute Fourier coefficients for all columns in matrix v

% M*M'					% test for ortho-normality
% data = sqrt(D) * M'*f	% re-compute data from Fourier coefficients 

% end of function cDFT.m

