function s = cFourierSeries(f,FFTswitch) 
% Create a string definition of a Fourier series using complex exponentials
%
% Use:  s = cFourierSeries(f,FFTswitch) 
%		x=[0:10]; y=eval (s)
%
% Input arguments:	
%   f = vector of Fourier coefficients returned by cDFT.m, or FFT.m
%	FFTswitch = 1 if input vector was generated by FFT.m,
%				else assume input vector was generated by cDFT.m = default
%
% Output arguments:  s = an executable string
%
% LNT 28-Feb-00

% Begin with some legality checks
if nargin < 2, FFTswitch = 0; end
if min(size(f)) ~= 1
	error('Input must be a vector');	
end

% first set up loop parameters
D = length(f);
if mod(D,2) == 1				% branch for D odd
	kmin = -(D-1)/2				% the largest negative harmonic number
	kmax = -kmin;				% the largets positive harmonic number
else 							% branch for D even
	kmin = -D/2					% the largest negative harmonic number
	kmax = -kmin-1;				% the largets positive harmonic number
end;

if FFTswitch==1
	f = fftshift(f) / D;		% re-order & rescale the coefficients
end

k = kmin;
s = ['(',num2str(f(1)),')*exp(',num2str(k),'*i*2*pi*x/L)'];
for k = kmin+1:kmax
	j = k-kmin+1;				% an index into vector f
	s = [s,' + (',num2str(f(j)),')*exp(',num2str(k),'*i*2*pi*x/L)'];
end;

