function s = cFourierSpectrum(f,FFTswitch,fundamental) 
% Display a complex Fourier spectrum in rectangular & polar forms
%
% Use:  s = cFourierSpectrum(f,FFTswitch,fundamental)
%
% Input:	f = vector of Fourier coefficients returned by cDFT.m, or FFT.m
%				format: f=[-D/2, -D/2 +1, ..., -1, 0, +1, ..., D/2 -1, D/2]  
%	FFTswitch = 1 if input vector was generated by FFT.m,
%				else assume input vector was generated by cDFT.m = default
%	fundamental = physical frequency of fundamental harmonic (used to scale
%					frequency axis).  default = 1 => frequency = harmonic number
%
% Output:  s = vector of frequencies which support f
%
% LNT 20-Mar-00.  30-Mar change the output quantities.

% Begin with some legality checks
if nargin < 3, fundamental = 1; end	% default = use harmonic number 
if nargin < 2, FFTswitch = 0; end	% default = fourier vector was computed with cDFT
if min(size(f)) ~= 1
	error('Input must be a vector');	
end

% deal with input format
D = length(f);
if FFTswitch==1
	f = fftshift(f) / D;		% re-order & rescale the coefficients for Matlab's FFT
end

% get endpoints of spectrum
if mod(D,2) == 1;				% branch for D odd
	kmin = -(D-1)/2;			% the largest negative harmonic number
	kmax = -kmin;				% the largets positive harmonic number
	k0 = round(D/2);			% index of DC coefficient
	
else 							% branch for D even
	kmin = -D/2;				% the largest negative harmonic number
	kmax = -kmin-1;				% the largets positive harmonic number
	k0 = D/2 + 1;				% index of DC coefficient
end;

% build support for f
s = [kmin:kmax]*fundamental;

% set up the 2x2 display
subplot(2,2,1), stem(s,real(f)) 
xlabel('Frequency'), ylabel('Real part')
subplot(2,2,2), stem(s,imag(f))
xlabel('Frequency'), ylabel('Imaginary part')
subplot(2,2,3), stem(s,abs(f))
xlabel('Frequency'), ylabel('Magnitude')
subplot(2,2,4), stem(s,angle(f))
xlabel('Frequency'), ylabel('Phase')

