function [v,x]=cIDFT(f,t)
%cIDFT - compute the Inverse Discrete Fourier Transform using complex exponentials
%
% Use: [v,x]=cIDFT(f,t)
%
% Input: 
%	f = vector of Fourier coefficients or matric of col vectors.  
%       Order is from -D/2 to +D/2 where D = length(L) = 
%		 number of data points in vector v.
% 	t = vector of sample angles 
%
% Output:
%	v = vector of sampled data or matrix of column data vectors
%   x = vector sample angles used to reconstruct the data

% LNT 06-Mar-03

[r,c] = size(f);		% check if f is a row or col vector
if r==1
	f=f';				% force data to be a column vector
end
D = length(f);			% dimensionality of the data vector

if nargin < 2
	t = D;
end

[M,x]=BuildCExp(t);	% build the transformational matrix

[r,c] = size(f);		% check if v is a row or col vector

v = sqrt(D) * M'*f;% text eqn. [4.17]

% end of function cIDFT.m
