% test_MakeTrig - a script to test MakeTrig.m
% LNT 20Feb03; add graphics 28Jan06; add 3rd example 27Sep2012

%% test 1: specify the number of points in the data vector
% Graphically compare discrete samples from MakeTrig with continuous trig
%   functions that are the expected answer.
D=6;                % pick any integer # of points               
[M,t]=MakeTrig(D)   % compute the transformation matrix M

% display the results graphically to verify rows of M visually
% Note that special cases (first row, and last row when D=even) would
%   require special handling to make the curves and points coincide.
s = sqrt(D/2);               % the scaling constant used to normalize M
ss = sqrt(D);                % special scaling constant used to normalize M
tt=0:0.1:2*pi;               % time on a fine scale
curveNum = [1:D];            % a counter for showing all the harmonics
harmNum = floor(curveNum/2);
figure; 
for r=curveNum
    plot(t,M(r,:),'k*','MarkerSize',12) % each row of M is a sampled sine or cosine
    hold on                     % let graphs overlap
    if mod(r,2) == 0			% branch for even curveNum
        if r==D  % special case of last term when D is even
            plot(tt,cos(harmNum(r)*tt)./ss,'r-')  
        else
            plot(tt,cos(harmNum(r)*tt)./s,'r-')
        end
    else                        % branch for odd curveNum
        if r==1  % special case of constant term
            plot(tt,cos(harmNum(r)*tt)./ss,'r-')
        else            
            plot(tt,sin(harmNum(r)*tt)./s,'r-')
        end
    end
    hold off                    % stop the overlapping
    xlabel('Sample angle'); ylabel('Amplitude')
    title(['Harmonic number ',num2str(harmNum(r))])
    legend('Samples','Continuous')
    pause  
end

% diagnostic test for orthonormality 
M*M'	% result will  be identity matrix when MakeTrig is correct

%% test 2: specify a vector of sample points on standard interval [0 2pi]
% Graph shows discrete samples from MakeTrig and input samples
D=6;      % use same number of points so we can compare M and M2              
tt = 2*pi*linspace(0,1,D+1);        % sample angles on standard interval
tt = tt(1:D);                       % drop the last point
[M2,t]=MakeTrig(tt)

% display the results graphically to verify visually
% Note that special cases (first row, and last row when D=even) 
%   require special handling to make the curves and points coincide.
s = sqrt(D/2);                  % the scaling constant used to normalize M
ss = sqrt(D);                % special scaling constant used to normalize M
curveNum = [1:D];
harmNum = floor(curveNum/2);
figure; 
for r=curveNum
    plot(t,M(r,:),'k*','MarkerSize',12) % each row is a sampled sine or cosine
    hold on                     % let graphs overlap
    if mod(r,2) == 0			% branch for even curveNum
        if r==D  % special case of last term when D is even
            plot(tt,cos(harmNum(r)*tt)./ss,'ro--','MarkerSize',12)  
        else
            plot(tt,cos(harmNum(r)*tt)./s,'ro--','MarkerSize',12)
        end
    else                        % branch for odd curveNum
        if r==1  % special case of constant term
            plot(tt,cos(harmNum(r)*tt)./ss,'ro--','MarkerSize',12)
        else            
            plot(tt,sin(harmNum(r)*tt)./s,'ro--','MarkerSize',12)
        end
    end
    hold off                    % stop the overlapping
    xlabel('Sample angle'); ylabel('Amplitude')
    title(['Harmonic number ',num2str(harmNum(r))])
    legend('MakeTrig','Samples')
    pause  
end

% diagnostic test for orthonormality 
M2*M2'	% result will  be identity matrix when MakeTrig is correct
M-M2    % should be matrix of zeros

%% test 3: specify a vector of sample points on physical interal [0 L]
% Graph results using physical interval [0 12]
D=6;      % use same number of points so we can compare M and M3
L=12;                           % physical length of the interval
tt = linspace(0,L,D+1);         % sample times on physical interval [0 L]
tt = tt(1:D);                   % drop the last point
[M3,t]=MakeTrig(tt)             % output t should be on standard interval [0 2pi]
T = t*L/(2*pi);         % rescale t to physical interval [0 L] for graphing

% display the results graphically to verify visually
theta = 2*pi*tt/L;         % rescale given sample times to interval [0 2pi]
s = sqrt(D/2);             % the scaling constant used to normalize M
ss = sqrt(D);              % special scaling constant used to normalize M
curveNum = [1:D];
harmNum = floor(curveNum/2);
figure; 
for r=curveNum
    plot(T,M(r,:),'k*','MarkerSize',12)          % each row is a sampled sine or cosine
    hold on                     % let graphs overlap
    if mod(r,2) == 0			% branch for even curveNum
        if r==D  % special case of last term when D is even
            plot(tt,cos(harmNum(r)*theta)./ss,'ro--','MarkerSize',12)  
        else
            plot(tt,cos(harmNum(r)*theta)./s,'ro--','MarkerSize',12)
        end
    else                        % branch for odd curveNum
        if r==1  % special case of constant term
            plot(tt,cos(harmNum(r)*theta)./ss,'ro--','MarkerSize',12)
        else            
            plot(tt,sin(harmNum(r)*theta)./s,'ro--','MarkerSize',12)
        end
    end
    hold off                    % stop the overlapping
    xlabel('Time'); ylabel('Amplitude')
    title(['Harmonic number ',num2str(harmNum(r))])
    legend('MakeTrig','Samples')
    axis([0 12 -1 1])
    pause  
end

% diagnostic test for orthonormality 
M3*M3'	% result will  be identity matrix when MakeTrig is correct
M3-M    % should be matrix of zeros